- © {new Date().getFullYear()} Thirukalyanam, The World's
- Leading Matchmaking Service™
+ © {new Date().getFullYear()} Thirukalyanam, The World's Leading
+ Matchmaking Service™
diff --git a/src/components/landing/AppQRCode.jsx b/src/components/landing/AppQRCode.jsx
index 013041b..ae17c87 100644
--- a/src/components/landing/AppQRCode.jsx
+++ b/src/components/landing/AppQRCode.jsx
@@ -4,8 +4,8 @@ import LazyImage from '../common/LazyImage';
const AppQRCode = () => {
return (
<>
-
-
+
+
{/* Left Content Section */}
@@ -171,7 +171,7 @@ const AppQRCode = () => {
*/}
-
+
{
return (
<>
-
+
{/* Logo Section */}
+
{/* Planet Icon */}
@@ -194,183 +228,191 @@ className="w-full max-w-sm rounded-[10px] shadow-xl overflow-hidden border-2 bor
>
-
+
- Age : {profile.age}
+ Age : {profile.age}
-
+
- Height: {profile.height}
+ Height: {profile.height}
+
+
+
+
+
+
+
+
+
+
+ {profile.salary}
+
+
+
+
+
+ {profile.location}
-
+
- {profile.religion}
+ {profile.caste}
+
+
+
+

+
+ {profile.zodiac1}
-
-
+
- {profile.education}
+ {profile.zodiac2}
-
-
-
-
-
- {profile.location}
-
-
-
-
-
-
);
};
return (
<>
-
- {/* Header */}
-
-
- Your Matching List
-
- Find your perfect match today
-
-
- {/* Swiper Container */}
-
-
+
+ {/* Header */}
+
- {profiles.map((profile) => (
-
-
-
- ))}
-
+
+ Your Matching List
+
+
+ Find your perfect match today
+
+
- {/* Custom Navigation Buttons */}
-
swiperRef.current?.swiper.slidePrev()}
- className="hidden sm:flex absolute left-0 top-1/2 -translate-y-1/2 z-10
+ {/* Swiper Container */}
+
+
+ {profiles.map((profile) => (
+
+
+
+ ))}
+
+
+ {/* Custom Navigation Buttons */}
+
swiperRef.current?.swiper.slidePrev()}
+ className="hidden sm:flex absolute left-0 top-1/2 -translate-y-1/2 z-10
bg-white/20 backdrop-blur-sm rounded-full flex items-center justify-center hover:bg-white/30 transition-all
w-12 h-12 rounded-full shadow-xl hover:shadow-2xl items-center justify-center "
- >
-
-
+ >
+
+
-
swiperRef.current?.swiper.slideNext()}
- className="hidden sm:flex absolute right-0 top-1/2 -translate-y-1/2 z-10
+ swiperRef.current?.swiper.slideNext()}
+ className="hidden sm:flex absolute right-0 top-1/2 -translate-y-1/2 z-10
bg-white/20 backdrop-blur-sm rounded-full flex items-center justify-center hover:bg-white/30 transition-all
w-12 h-12 rounded-full shadow-xl hover:shadow-2xl items-center justify-center transition-all"
+ >
+
+
+
+
+ {/* View All Button */}
+
-
-
+
navigate("/matches")}
+ >
+ View All Matches
+
+
- {/* View All Button */}
-
- navigate("/matches")}
- >
- View All Matches
-
-
+ {/* Custom Swiper Styles */}
+
-
- {/* Custom Swiper Styles */}
-
-
>
- )
-}
+ );
+};
-export default MatchingList
+export default MatchingList;
diff --git a/src/components/common/Threemarquee.jsx b/src/components/common/Threemarquee.jsx
index 195459f..7432bfc 100644
--- a/src/components/common/Threemarquee.jsx
+++ b/src/components/common/Threemarquee.jsx
@@ -2,6 +2,7 @@ import ThreeDScrollTriggerRow, {
ThreeDScrollTriggerContainer,
} from "../lightswind/ThreeDScrollTrigger";
import React, { useState } from "react";
+
const reviews = [
{
name: "Aria Thompson",
@@ -28,51 +29,41 @@ const reviews = [
"From landing pages to complex dashboards, Lightswind UI makes building visually consistent UIs effortless and fun.",
},
{
- name: "Liam Patel",
- company: "NextGen Interfaces",
+ name: "Sarah Mitchell",
+ company: "DesignFlow Co",
image:
- "https://images.unsplash.com/photo-1506794778202-cad84cf45f1d?auto=format&fit=facearea&w=96&h=96&facepad=2",
+ "https://images.unsplash.com/photo-1494790108377-be9c29b29330?auto=format&fit=facearea&w=96&h=96&facepad=2",
review:
- "From landing pages to complex dashboards, Lightswind UI makes building visually consistent UIs effortless and fun.",
+ "The component library is extensive and well-documented. Saved us months of development time.",
},
{
- name: "Liam Patel",
- company: "NextGen Interfaces",
+ name: "James Chen",
+ company: "TechVision Labs",
image:
- "https://images.unsplash.com/photo-1506794778202-cad84cf45f1d?auto=format&fit=facearea&w=96&h=96&facepad=2",
+ "https://images.unsplash.com/photo-1507003211169-0a1dd7228f2d?auto=format&fit=facearea&w=96&h=96&facepad=2",
review:
- "From landing pages to complex dashboards, Lightswind UI makes building visually consistent UIs effortless and fun.",
+ "Outstanding support and continuous updates. Lightswind UI keeps getting better every release.",
},
{
- name: "Liam Patel",
- company: "NextGen Interfaces",
+ name: "Emma Davis",
+ company: "PixelPerfect Studios",
image:
- "https://images.unsplash.com/photo-1506794778202-cad84cf45f1d?auto=format&fit=facearea&w=96&h=96&facepad=2",
+ "https://images.unsplash.com/photo-1438761681033-6461ffad8d80?auto=format&fit=facearea&w=96&h=96&facepad=2",
review:
- "From landing pages to complex dashboards, Lightswind UI makes building visually consistent UIs effortless and fun.",
- },
- {
- name: "Liam Patel",
- company: "NextGen Interfaces",
- image:
- "https://images.unsplash.com/photo-1506794778202-cad84cf45f1d?auto=format&fit=facearea&w=96&h=96&facepad=2",
- review:
- "From landing pages to complex dashboards, Lightswind UI makes building visually consistent UIs effortless and fun.",
+ "Responsive by default and looks amazing on all devices. This is exactly what we needed.",
},
];
export default function ThreeScrollTrigger() {
- // Split reviews across 3 rows for masonry feel
- // Split reviews across 3 rows
- const row1 = [reviews[0], reviews[1]];
- const row2 = [reviews[2], reviews[3]];
- const row3 = [reviews[4], reviews[5], reviews[6]];
+ // Split reviews into 2 rows with 3 cards each
+ const row1 = reviews.slice(0, 3);
+ const row2 = reviews.slice(3, 6);
const [paused, setPaused] = useState(false);
- return (
-
-
-
+ return (
+
+
+ {/* Row 1 - 3 Cards scrolling right */}
{row1.map((rev, idx) => (
@@ -86,48 +77,54 @@ export default function ThreeScrollTrigger() {
-
+ {/* Row 2 - 3 Cards scrolling left */}
+
{row2.map((rev, idx) => (
- setPaused(true)}
- onMouseLeave={() => setPaused(false)} />
+ setPaused(true)}
+ onMouseLeave={() => setPaused(false)}
+ />
))}
-
- {/*
-
- {row3.map((rev, idx) => (
- setPaused(true)}
- onMouseLeave={() => setPaused(false)} />
- ))}
-
- */}
);
}
// Card component for clarity and reuse
-function ReviewCard({ name, company, image, review ,onMouseEnter, onMouseLeave}) {
+function ReviewCard({
+ name,
+ company,
+ image,
+ review,
+ onMouseEnter,
+ onMouseLeave,
+}) {
return (
-
-
+
+

-
-
- {review}
+
+ "{review}"
);
-}
+}
\ No newline at end of file